==> istio-model-v1alpha3-6.6.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPRetryFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRetryFluentImpl<A extends HTTPRetryFluent<A>> extends BaseFluent<A> implements HTTPRetryFluent<A>{
  public HTTPRetryFluentImpl() {
  }
  public HTTPRetryFluentImpl(HTTPRetry instance) {
    this.withAttempts(instance.getAttempts()); 
    this.withPerTryTimeout(instance.getPerTryTimeout()); 
    this.withRetryOn(instance.getRetryOn()); 
    this.withRetryRemoteLocalities(instance.getRetryRemoteLocalities()); 
  }
  private Integer attempts;
  private String perTryTimeout;
  private String retryOn;
  private Boolean retryRemoteLocalities;
  public Integer getAttempts() {
    return this.attempts;
  }
  public A withAttempts(Integer attempts) {
    this.attempts=attempts; return (A) this;
  }
  public Boolean hasAttempts() {
    return this.attempts != null;
  }
  public String getPerTryTimeout() {
    return this.perTryTimeout;
  }
  public A withPerTryTimeout(String perTryTimeout) {
    this.perTryTimeout=perTryTimeout; return (A) this;
  }
  public Boolean hasPerTryTimeout() {
    return this.perTryTimeout != null;
  }
  public String getRetryOn() {
    return this.retryOn;
  }
  public A withRetryOn(String retryOn) {
    this.retryOn=retryOn; return (A) this;
  }
  public Boolean hasRetryOn() {
    return this.retryOn != null;
  }
  public Boolean getRetryRemoteLocalities() {
    return this.retryRemoteLocalities;
  }
  public A withRetryRemoteLocalities(Boolean retryRemoteLocalities) {
    this.retryRemoteLocalities=retryRemoteLocalities; return (A) this;
  }
  public Boolean hasRetryRemoteLocalities() {
    return this.retryRemoteLocalities != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPRetryFluentImpl that = (HTTPRetryFluentImpl) o;
    if (attempts != null ? !attempts.equals(that.attempts) :that.attempts != null) return false;
    if (perTryTimeout != null ? !perTryTimeout.equals(that.perTryTimeout) :that.perTryTimeout != null) return false;
    if (retryOn != null ? !retryOn.equals(that.retryOn) :that.retryOn != null) return false;
    if (retryRemoteLocalities != null ? !retryRemoteLocalities.equals(that.retryRemoteLocalities) :that.retryRemoteLocalities != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(attempts,  perTryTimeout,  retryOn,  retryRemoteLocalities,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (attempts != null) { sb.append("attempts:"); sb.append(attempts + ","); }
    if (perTryTimeout != null) { sb.append("perTryTimeout:"); sb.append(perTryTimeout + ","); }
    if (retryOn != null) { sb.append("retryOn:"); sb.append(retryOn + ","); }
    if (retryRemoteLocalities != null) { sb.append("retryRemoteLocalities:"); sb.append(retryRemoteLocalities); }
    sb.append("}");
    return sb.toString();
  }
  public A withRetryRemoteLocalities() {
    return withRetryRemoteLocalities(true);
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPRetryFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRetryFluentImpl<A extends HTTPRetryFluent<A>> extends BaseFluent<A> implements HTTPRetryFluent<A>{
  public HTTPRetryFluentImpl() {
  }
  public HTTPRetryFluentImpl(HTTPRetry instance) {
    if (instance != null) {
      this.withAttempts(instance.getAttempts());
      this.withPerTryTimeout(instance.getPerTryTimeout());
      this.withRetryOn(instance.getRetryOn());
      this.withRetryRemoteLocalities(instance.getRetryRemoteLocalities());
    }
  }
  private Integer attempts;
  private String perTryTimeout;
  private String retryOn;
  private Boolean retryRemoteLocalities;
  public Integer getAttempts() {
    return this.attempts;
  }
  public A withAttempts(Integer attempts) {
    this.attempts=attempts; return (A) this;
  }
  public Boolean hasAttempts() {
    return this.attempts != null;
  }
  public String getPerTryTimeout() {
    return this.perTryTimeout;
  }
  public A withPerTryTimeout(String perTryTimeout) {
    this.perTryTimeout=perTryTimeout; return (A) this;
  }
  public Boolean hasPerTryTimeout() {
    return this.perTryTimeout != null;
  }
  public String getRetryOn() {
    return this.retryOn;
  }
  public A withRetryOn(String retryOn) {
    this.retryOn=retryOn; return (A) this;
  }
  public Boolean hasRetryOn() {
    return this.retryOn != null;
  }
  public Boolean getRetryRemoteLocalities() {
    return this.retryRemoteLocalities;
  }
  public A withRetryRemoteLocalities(Boolean retryRemoteLocalities) {
    this.retryRemoteLocalities=retryRemoteLocalities; return (A) this;
  }
  public Boolean hasRetryRemoteLocalities() {
    return this.retryRemoteLocalities != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRetryFluentImpl that = (HTTPRetryFluentImpl) o;
    if (!java.util.Objects.equals(attempts, that.attempts)) return false;

    if (!java.util.Objects.equals(perTryTimeout, that.perTryTimeout)) return false;

    if (!java.util.Objects.equals(retryOn, that.retryOn)) return false;

    if (!java.util.Objects.equals(retryRemoteLocalities, that.retryRemoteLocalities)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(attempts,  perTryTimeout,  retryOn,  retryRemoteLocalities,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (attempts != null) { sb.append("attempts:"); sb.append(attempts + ","); }
    if (perTryTimeout != null) { sb.append("perTryTimeout:"); sb.append(perTryTimeout + ","); }
    if (retryOn != null) { sb.append("retryOn:"); sb.append(retryOn + ","); }
    if (retryRemoteLocalities != null) { sb.append("retryRemoteLocalities:"); sb.append(retryRemoteLocalities); }
    sb.append("}");
    return sb.toString();
  }
  public A withRetryRemoteLocalities() {
    return withRetryRemoteLocalities(true);
  }
  
}
